<?php
$mts_options = get_option(MTS_THEME_NAME);
if ( ! function_exists( 'mts_meta' ) ) {
	/**
	 * Display necessary tags in the <head> section.
	 */
	function mts_meta(){
		global $mts_options, $post;
		?>

		<?php if ( !empty( $mts_options['mts_favicon'] ) ) { ?>
			<link rel="icon" href="<?php echo esc_url( $mts_options['mts_favicon'] ); ?>" type="image/x-icon" />
		<?php } elseif ( function_exists( 'has_site_icon' ) && has_site_icon() ) { ?>
			<?php printf( '<link rel="icon" href="%s" sizes="32x32" />', esc_url( get_site_icon_url( 32 ) ) ); ?>
			<?php sprintf( '<link rel="icon" href="%s" sizes="192x192" />', esc_url( get_site_icon_url( 192 ) ) ); ?>
		<?php } ?>

		<?php if ( !empty( $mts_options['mts_metro_icon'] ) ) { ?>
			<!-- IE10 Tile.-->
			<meta name="msapplication-TileColor" content="#FFFFFF">
			<meta name="msapplication-TileImage" content="<?php echo esc_url( $mts_options['mts_metro_icon'] ); ?>">
		<?php } elseif ( function_exists( 'has_site_icon' ) && has_site_icon( ) ) { ?>
			<?php printf( '<meta name="msapplication-TileImage" content="%s">', esc_url( get_site_icon_url( 270 ) ) ); ?>
		<?php } ?>

		<?php if ( !empty( $mts_options['mts_touch_icon'] ) ) { ?>
			<!--iOS/android/handheld specific -->
			<link rel="apple-touch-icon-precomposed" href="<?php echo esc_url( $mts_options['mts_touch_icon'] ); ?>" />
		<?php } elseif ( function_exists( 'has_site_icon' ) && has_site_icon() ) { ?>
			<?php printf( '<link rel="apple-touch-icon-precomposed" href="%s">', esc_url( get_site_icon_url( 180 ) ) ); ?>
		<?php } ?>

		<?php if ( ! empty( $mts_options['mts_responsive'] ) ) { ?>
			<meta name="viewport" content="width=device-width, initial-scale=1">
			<meta name="apple-mobile-web-app-capable" content="yes">
			<meta name="apple-mobile-web-app-status-bar-style" content="black">
		<?php } ?>

		<?php if($mts_options['mts_prefetching'] == '1') { ?>
			<?php if (is_front_page()) { ?>
				<?php $my_query = new WP_Query('posts_per_page=1'); while ($my_query->have_posts()) : $my_query->the_post(); ?>
				<link rel="prefetch" href="<?php the_permalink(); ?>">
				<link rel="prerender" href="<?php the_permalink(); ?>">
				<?php endwhile; wp_reset_postdata(); ?>
			<?php } elseif (is_singular()) { ?>
				<link rel="prefetch" href="<?php echo esc_url( home_url() ); ?>">
				<link rel="prerender" href="<?php echo esc_url( home_url() ); ?>">
			<?php } ?>
		<?php } ?>

		<meta itemprop="name" content="<?php bloginfo( 'name' ); ?>" />
		<meta itemprop="url" content="<?php echo esc_url( site_url() ); ?>" />

		<?php if ( is_singular() ) { ?>
			<?php $user_info = get_userdata($post->post_author); ?>
			<?php if ( $user_info && ! empty( $user_info->first_name ) && ! empty( $user_info->last_name ) ) : ?>
				<meta itemprop="creator accountablePerson" content="<?php echo $user_info->first_name.' '.$user_info->last_name; ?>" />
			<?php endif; ?>
		<?php }
	}
}

/*------------[ Head ]-------------*/
if ( ! function_exists( 'mts_head' ) ){
	/**
	 * Display header code from Theme Options.
	 */
	function mts_head() {
	global $mts_options;
?>
<?php echo $mts_options['mts_header_code']; ?>
<?php }
}
add_action('wp_head', 'mts_head');

/*------------[ Copyrights ]-------------*/
if ( ! function_exists( 'mts_copyrights_credit' ) ) {
	/**
	 * Display the footer copyright.
	 */
	function mts_copyrights_credit() { 
	global $mts_options
?>
<!--start copyrights-->
<div class="row" id="copyright-note">
<span><a href="<?php echo home_url(); ?>/" title="<?php bloginfo('description'); ?>"><?php bloginfo('name'); ?></a> Copyright &copy; <?php echo date("Y") ?>.</span>
<div class="to-top"><?php echo $mts_options['mts_copyrights']; ?></div>
</div>
<!--end copyrights-->
<?php }
}

/*------------[ footer ]-------------*/
if ( ! function_exists( 'mts_footer' ) ) {
	/**
	 * Display the analytics code in the footer.
	 */
	function mts_footer() { 
	global $mts_options;
?>
	<?php if ($mts_options['mts_analytics_code'] != '') { ?>
	<!--start footer code-->
		<?php echo $mts_options['mts_analytics_code']; ?>
	<!--end footer code-->
	<?php }
	}
}

/*------------[ breadcrumb ]-------------*/
if (!function_exists('mts_the_breadcrumb')) {
	/**
	 * Display the breadcrumbs.
	 */
	function mts_the_breadcrumb() {
		if ( is_front_page() ) {
			return;
		}
		echo '<div typeof="v:Breadcrumb" class="root"><a rel="v:url" property="v:title" href="';
		echo home_url();
		echo '">'.sprintf( __( "Home","magxp"));
		echo '</a><span class="arrow"></span></div>';
		if (is_category() || is_single()) {
			$categories = get_the_category();
			$output = '';
			if($categories){
				foreach($categories as $category) {
					echo '<div typeof="v:Breadcrumb"><a href="'.get_category_link( $category->term_id ).'" rel="v:url" property="v:title">'.$category->cat_name.'</a><span class="arrow"></span></div>';
				}
			}
		} elseif (is_page()) {
			echo '<div typeof="v:Breadcrumb"><span property="v:title">';
			the_title();
			echo '</span><span class="arrow"></span></div>';
		}
	}
}

/**
 * Display schema-compliant the_category()
 *
 * @param string $separator
 */
function mts_the_category( $separator = ', ' ) {
	$categories = get_the_category();
	$count = count($categories);
	foreach ( $categories as $i => $category ) {
		echo '<a href="' . esc_url( get_category_link( $category->term_id ) ) . '" title="' . sprintf( __( "View all posts in %s", 'magxp' ), esc_attr( $category->name ) ) . '">' . esc_html( $category->name ).'</a>';
		if ( $i < $count - 1 )
			echo $separator;
	}
}

/**
 * Display schema-compliant the_tags()
 *
 * @param string $before
 * @param string $sep
 * @param string $after
 */
function mts_the_tags($before = '', $sep = ', ', $after = '</div>') {
	if ( empty( $before ) ) {
		$before = '<div class="tags border-bottom">'.__('Tags: ', 'magxp' );
	}

	$tags = get_the_tags();
	if (empty( $tags ) || is_wp_error( $tags ) ) {
		return;
	}
	$tag_links = array();
	foreach ($tags as $tag) {
		$link = get_tag_link($tag->term_id);
		$tag_links[] = '<a href="' . esc_url( $link ) . '" rel="tag">' . $tag->name . '</a>';
	}
	echo $before.join($sep, $tag_links).$after;
}

if (!function_exists('mts_pagination')) {
	/**
	 * Display the pagination.
	 *
	 * @param string $pages
	 * @param int $range
	 */
	function mts_pagination($pages = '', $range = 3) {
		$mts_options = get_option(MTS_THEME_NAME);
		if (isset($mts_options['mts_pagenavigation_type']) && $mts_options['mts_pagenavigation_type'] == '1' ) { // numeric pagination
			the_posts_pagination( array(
				'mid_size' => 3,
				'prev_text' => "<i class='fa fa-angle-left'></i>",
				'next_text' => "<i class='fa fa-angle-right'></i>",
			) );
		} else { // traditional or ajax pagination
			?>
			<div class="pagination pagination-previous-next">
			<ul>
				<li class="nav-previous"><?php next_posts_link( '&larr; '. __( 'Older Posts', 'magxp' ) ); ?></li>
				<li class="nav-next"><?php previous_posts_link( __( 'Newer Posts', 'magxp' ).' &rarr;' ); ?></li>
			</ul>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'mts_cart' ) ) {
	/**
	 * Display the woo-commerce login/register link and the cart.
	 */
	function mts_cart() { 
	   if (mts_is_wc_active()) {
	   global $mts_options;
?>
<div class="mts-cart">
	<?php global $woocommerce; ?>
	<?php if ( is_user_logged_in() ) { ?>
		<a href="<?php echo esc_url( get_permalink( get_option('woocommerce_myaccount_page_id') ) ); ?>" title="<?php _e('My Account', 'magxp' ); ?>"><i class="fa fa-user"></i> <?php _e('My Account', 'magxp' ); ?></a>
	<?php } else { ?>
		<a href="<?php echo esc_url( get_permalink( get_option('woocommerce_myaccount_page_id') ) ); ?>" title="<?php _e('Login / Register', 'magxp' ); ?>"><i class="fa fa-user"></i> <?php _e('Login ', 'magxp' ); ?></a>
	<?php } ?>
	<a class="cart-contents" href="<?php echo esc_url( $woocommerce->cart->get_cart_url() ); ?>" title="<?php _e('View your shopping cart', 'magxp' ); ?>"><i class="fa fa-shopping-cart"></i> <?php echo sprintf(_n('%d item', '%d items', $woocommerce->cart->cart_contents_count, 'magxp' ), $woocommerce->cart->cart_contents_count);?> - <?php echo $woocommerce->cart->get_cart_total(); ?></a>
</div>
<?php } 
	}
}


if (!function_exists('mts_related_posts')) {
	/**
	 * Display the related posts.
	 */
	function mts_related_posts() {
		$post_id = get_the_ID();
		$mts_options = get_option(MTS_THEME_NAME); ?>	
			<!-- Start Related Posts -->
			<?php 
			$empty_taxonomy = false;
			if (empty($mts_options['mts_related_posts_taxonomy']) || $mts_options['mts_related_posts_taxonomy'] == 'tags') {
				// related posts based on tags
				$tags = get_the_tags($post_id);
				if (empty($tags)) { 
					$empty_taxonomy = true;
				} else {
					$tag_ids = array(); 
					foreach($tags as $individual_tag) {
						$tag_ids[] = $individual_tag->term_id; 
					}
					$args = array( 'tag__in' => $tag_ids, 
						'post__not_in' => array($post_id),
						'posts_per_page' => isset( $mts_options['mts_related_postsnum'] ) ? $mts_options['mts_related_postsnum'] : 3,
						'ignore_sticky_posts' => 1, 
						'orderby' => 'rand' 
					);
				}
			 } else {
				// related posts based on categories
				$categories = get_the_category($post_id);
				if (empty($categories)) { 
					$empty_taxonomy = true;
				} else {
					$category_ids = array(); 
					foreach($categories as $individual_category) 
						$category_ids[] = $individual_category->term_id; 
					$args = array( 'category__in' => $category_ids, 
						'post__not_in' => array($post_id),
						'posts_per_page' => $mts_options['mts_related_postsnum'],  
						'ignore_sticky_posts' => 1, 
						'orderby' => 'rand' 
					);
				}
			 }
			if (!$empty_taxonomy) {
			$my_query = new WP_Query( $args ); if( $my_query->have_posts() ) {
				echo '<div class="related-posts">';
				echo '<h4>'.__('Related Posts', 'magxp' ).'</h4>';
				$posts_per_row = 3;
				$j = 0;
				while( $my_query->have_posts() ) { $my_query->the_post(); ?>
				<article class="latestPost excerpt  <?php echo (++$j % $posts_per_row == 0) ? 'last' : ''; ?>">
					<div class="featured-wrap clearfix">
						<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php echo esc_attr( get_the_title() ); ?>" class="post-image post-image-left"<?php if (mts_get_category_color()) { echo ' style="border-color: '.mts_get_category_color().';"'; } ?>>
							<?php echo '<div class="featured-thumbnail">'; the_post_thumbnail('magxp-featured',array('title' => '')); echo '</div>'; ?>
							<?php if (function_exists('wp_review_show_total')) wp_review_show_total(true, 'latestPost-review-wrapper'); ?>
						</a>
						<?php $category = get_the_category(get_the_ID());  if(!empty($category)){ ?>
						<div class="inner-categories"<?php if (mts_get_category_color()) { echo ' style="background: '.mts_get_category_color().';"'; } ?>><?php echo '<a href="'.get_category_link( $category[0]->term_id ).'" title="' . esc_attr( sprintf( __( "View all posts in %s", 'magxp' ), $category[0]->name ) ) . '">'.$category[0]->cat_name.'</a>'; ?></div>
						<?php } ?>
					</div>
					<header>
						<h2 class="title front-view-title">
							<a href="<?php the_permalink() ?>" title="<?php the_title(); ?>"><?php 
								$text = get_the_title();
								$text_content = wp_trim_words( $text, 6, ' ...' );
								echo $text_content; ?>
							</a>
						</h2>
					<?php mts_the_related_postinfo(); ?>
					</header>
				</article><!--.post.excerpt-->
				<?php } echo '</div>'; }} wp_reset_postdata(); ?>
			<!-- .related-posts -->
		<?php //}
	}
}


if ( ! function_exists('mts_the_postinfo' ) ) {
	function mts_the_postinfo( $section = 'home' ) {
		$mts_options = get_option( MTS_THEME_NAME );
		$opt_key = 'mts_'.$section.'_headline_meta_info';
		
		if ( isset( $mts_options[ $opt_key ] ) && is_array( $mts_options[ $opt_key ] ) && array_key_exists( 'enabled', $mts_options[ $opt_key ] ) ) {
			$headline_meta_info = $mts_options[ $opt_key ]['enabled'];
		} else {
			$headline_meta_info = array();
		}
		if ( ! empty( $headline_meta_info ) ) { ?>
			<div class="post-info">
				<?php foreach( $headline_meta_info as $key => $meta ) { mts_the_postinfo_item( $key ); } ?>
			</div>
		<?php }
	}
}
if ( ! function_exists('mts_the_postinfo_item' ) ) {
	function mts_the_postinfo_item( $item ) {
		switch ( $item ) {
			case 'author':
			?>
				<span class="theauthor"><?php if(!is_single()){ echo __('By','magxp').'&nbsp;'; } ?><?php if(is_single()){ ?><i class="fa fa-user"></i>&nbsp;<?php } ?><span><?php the_author_posts_link(); ?></span></span>
			<?php
			break;
			case 'date':
			?>
				<span class="thetime updated"><?php if(is_single()){ ?><i class="fa fa-calendar"></i>&nbsp;<?php } ?><span><?php the_time( get_option( 'date_format' ) ); ?></span></span>
			<?php
			break;
			case 'category':
			?>
				<span class="thecategory"><?php if(is_single()){ ?><i class="fa fa-tags"></i>&nbsp;<?php } ?><?php mts_the_category(', ') ?></span>
			<?php
			break;
			case 'comment':
			?>
				<span class="thecomment"><a href="<?php comments_link(); ?>" itemprop="interactionCount"><?php if(is_single()){ ?><i class="fa fa-comments"></i>&nbsp;<?php } ?><?php echo comments_number();?></a></span>
			<?php
			break;
		}
	}
}

if ( ! function_exists('mts_the_related_postinfo' ) ) {
	function mts_the_related_postinfo( $section = 'related' ) {
		$mts_options = get_option( MTS_THEME_NAME );
		$opt_key = 'mts_'.$section.'_headline_meta_info';
		
		if ( isset( $mts_options[ $opt_key ] ) && is_array( $mts_options[ $opt_key ] ) && array_key_exists( 'enabled', $mts_options[ $opt_key ] ) ) {
			$headline_meta_info = $mts_options[ $opt_key ]['enabled'];
		} else {
			$headline_meta_info = array();
		}
		if ( ! empty( $headline_meta_info ) ) { ?>
			<div class="post-info">
				<?php foreach( $headline_meta_info as $key => $meta ) { mts_the_related_postinfo_item( $key ); } ?>
			</div>
		<?php }
	}
}
if ( ! function_exists('mts_the_related_postinfo_item' ) ) {
	function mts_the_related_postinfo_item( $item ) {
		switch ( $item ) {
			case 'author':
			?>
				<span class="theauthor"><?php _e('By','magxp'); ?><span>&nbsp;<?php the_author_posts_link(); ?></span></span>
			<?php
			break;
			case 'date':
			?>
				<span class="thetime updated"><span><?php the_time( get_option( 'date_format' ) ); ?></span></span>
			<?php
			break;
			case 'category':
			if(is_single()){
			?>
				<span class="thecategory"><?php mts_the_category(', ') ?></span>
			<?php
			}
			break;
			case 'comment':
			if(is_single()){
			?>
				<span class="thecomment"><a href="<?php comments_link(); ?>" itemprop="interactionCount"><?php echo comments_number();?></a></span>
			<?php
			}
			break;
		}
	}
}

if (!function_exists('mts_social_buttons')) {
	function mts_social_buttons() {
		$mts_options = get_option( MTS_THEME_NAME );

		if ( isset( $mts_options['mts_social_buttons'] ) && is_array( $mts_options['mts_social_buttons'] ) && array_key_exists( 'enabled', $mts_options['mts_social_buttons'] ) ) {
			$buttons = $mts_options['mts_social_buttons']['enabled'];
		} else {
			$buttons = array();
		}

		if ( ! empty( $buttons ) ) {
		?>
			<!-- Start Share Buttons -->
			<div class="shareit <?php echo $mts_options['mts_social_button_position']; ?>">
				<?php foreach( $buttons as $key => $button ) { mts_social_button( $key ); } ?>
			</div>
			<!-- end Share Buttons -->
		<?php
		}
	}
}

if ( ! function_exists('mts_social_button' ) ) {
	function mts_social_button( $button ) {
		$mts_options = get_option( MTS_THEME_NAME );
		switch ( $button ) {
			case 'facebookshare':
            ?>
                <!-- Facebook Share-->
                <span class="share-item facebooksharebtn">
                    <div class="fb-share-button" data-layout="button_count"></div>
                </span>
            <?php
            break;
			case 'twitter':
			?>
				<!-- Twitter -->
				<span class="share-item twitterbtn">
					<a href="https://twitter.com/share" class="twitter-share-button" data-via="<?php echo $mts_options['mts_twitter_username']; ?>">Tweet</a>
				</span>
			<?php
			break;
			case 'gplus':
			?>
				<!-- GPlus -->
				<span class="share-item gplusbtn">
					<g:plusone size="medium"></g:plusone>
				</span>
			<?php
			break;
			case 'facebook':
			?>
				<!-- Facebook -->
				<span class="share-item facebookbtn">
					<div id="fb-root"></div>
					<div class="fb-like" data-send="false" data-layout="button_count" data-width="150" data-show-faces="false"></div>
				</span>
			<?php
			break;
			case 'pinterest':
				global $post;
			?>
				<!-- Pinterest -->
				<span class="share-item pinbtn">
					<a href="http://pinterest.com/pin/create/button/?url=<?php the_permalink(); ?>&media=<?php $thumb = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), 'large' ); echo $thumb['0']; ?>&description=<?php the_title(); ?>" class="pin-it-button" count-layout="horizontal">Pin It</a>
				</span>
			<?php
			break;
			case 'linkedin':
			?>
				<!--Linkedin -->
				<span class="share-item linkedinbtn">
					<script type="IN/Share" data-url="<?php get_permalink(); ?>"></script>
				</span>
			<?php
			break;
			case 'stumble':
			?>
				<!-- Stumble -->
				<span class="share-item stumblebtn">
					<su:badge layout="1"></su:badge>
				</span>
			<?php
			break;
		}
	}
}

/*------------[ Class attribute for <article> element ]-------------*/
if ( ! function_exists( 'mts_article_class' ) ) {
	function mts_article_class() {
		$mts_options = get_option( MTS_THEME_NAME );
		$class = '';
		
		// sidebar or full width
		if ( mts_custom_sidebar() == 'mts_nosidebar' ) {
			$class = 'ss-full-width';
		} else {
			$class = 'article';
		}
		
		echo $class;
	}
}

/*------------[ Class attribute for #page element ]-------------*/
if ( ! function_exists( 'mts_single_page_class' ) ) {
	function mts_single_page_class() {
		$class = '';

		if ( is_single() || is_page() ) {

			$class = 'single';

			$header_animation = mts_get_post_header_effect();
			if ( !empty( $header_animation )) $class .= ' '.$header_animation;
		}

		echo $class;
	}
}

if ( ! function_exists( 'mts_archive_post' ) ) {
	function mts_archive_post( $layout = '0' ) {

		$mts_options = get_option(MTS_THEME_NAME);

		if( !empty($mts_options['mts_homepage_layout']) ) {
			$archive_post_layout = 'layout-2';
		} else {
			$archive_post_layout = 'layout-1';
		}

		get_template_part( 'templates/archive-post', $archive_post_layout );
	}
}
